acgc.stats API documentation

# acgc.stats

A collection of statistical methods

The contents of all submodules are imported into `acgc.stats`. For example, `acgc.stats.sma` is the function `acgc.stats.bivariate_lines.sma` within `acgc.stats.bivariate_lines`.

Useful functions include BivariateStatistics, line fitting methods (sma, sen, york), weighted statistics (wmean, wmedian, wcov, wcorr, etc.), partial_corr, among others. See `help(acgc.stats)` for complete list of methods.

See documentation within submodules.

View Source

     1#!/usr/bin/env python3
     2# -*- coding: utf-8 -*-
     3'''A collection of statistical methods
     4
     5The contents of all submodules are imported into `acgc.stats`.
     6For example, `acgc.stats.sma` is the function `acgc.stats.bivariate_lines.sma`
     7within `acgc.stats.bivariate_lines`.
     8
     9Useful functions include BivariateStatistics, line fitting methods (sma, sen, york),
    10weighted statistics (wmean, wmedian, wcov, wcorr, etc.), partial_corr, among others.
    11See ``help(acgc.stats)`` for complete list of methods.
    12
    13See documentation within submodules.
    14'''
    15
    16from .bivariate import *
    17from .bivariate_lines import *
    18from .partial_corr import *
    19from .timeseries import *
    20from .weighted import *
    21
    22# Other sub-modules that are not imported because of
    23# better options or limited applications
    24# from .tapply import tapply    # use groupby in pandas and xarray
    25# from .sma_warton_fit import * # Use sma
    26try:
    27    # Requires R and rpy2
    28    from .loess import loess
    29except ModuleNotFoundError:
    30    def loess(*args, **kwargs):
    31        raise ModuleNotFoundError('loess function requires installation of R and rpy2. See documentation for details.')
    32    # Skip
    33    pass

def loess(*args, **kwargs): View Source

    31    def loess(*args, **kwargs):
    32        raise ModuleNotFoundError('loess function requires installation of R and rpy2. See documentation for details.')